==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/admin/inc/function.php <==
<?
  define('SESSIONTIMEOUT', 240);
  define('DEFAULTRIGHTS', "UML");

  // Validates the current session  
  function checksession()
  { 
    global $alang;

    $sess = true;

    if (!$_SESSION["EMAIL"]) $sess = false; else
    if ($_SESSION["TIMESTAMP"] + mktime(SESSIONTIMEOUT / 60) < time()) $sess = false;
    if (!$sess)
    {     
      // Open login page in parent window
      $dieredirect = '<body onload="window.open(\'index.html?message='.urlencode($alang["TStrings_wa_str6"]).'\',\'_top\');"></body>';
      //header("Location: index.html?message=" . urlencode($alang["SESSION"]));
      die($dieredirect);
    }
  }
  function checkadminaccess()
  {
   if ($_SESSION["ACCOUNT"]!='ADMIN'){
   header("Location: index.html?message=" . urlencode($alang[SESSION]));
   die();
   } 
  }

  function getstrvalue($value)
  {
    $value = str_replace("'","\'",$value);
    if ($value) return $value; else return "";
  }  

  function getlanguagelist()
  {
    global $lang_settings, $language;
    while(list($index, $value) = each($lang_settings))
      @$langs .= addselectoption($index, $value[0], $language);

    return $langs;
  }

  function getskinlist()
  {
    global $layout_settings, $layout;

    while(list($index, $value) = each($layout_settings))
      @$skins .= addselectoption($index, $value[0], $layout);

    return $skins;
  }

  function addselectoption($value, $label, $selected)
  {
    $option = '<option value="' . $value . '" ' . ($selected==$value?"selected":"") . '>' . $label . '</option>';
    return $option;
  }

  function getusermailboxpath($mailpath, $usermailboxpath)
  {
    return getfilevarpath($usermailboxpath, $mailpath);
  }
  
  function getdomainvalue($value,$isremote = 0)
  {
    $pos = strpos($value, "@");
    if ($pos) $value = substr($value, $pos+1, strlen($value));
    return $value;
  }

  function getaliasvalue($value)
  {
    $pos = strpos($value, "@");
    if ($pos) $value = substr($value, 0, $pos);
    return $value;
  }
  function mkdirtree($fpath)
  {
    if($fpath!="" && !file_exists($fpath))
    {
       $fpath2=str_replace("\\","/",$fpath);
       $exparr=explode("/",$fpath2);

       for ($i=0;$i<count($exparr);$i++)
       {
         $dirline.= $exparr[$i]."/";
         if(!file_exists($dirline)) @mkdir($dirline,0750);
       }
    }

    return true;
  }
  function checkapiobject()
  {
    global $api;
    
    if (!$api) $api = createobject("api"); 

  }
  
  function isuserright($right)
  {
    if ($_SESSION["RIGHTS"] == "*") return true;
    return (strpos($_SESSION["RIGHTS"], $right) === false)?false:true;
  }

  function getuserrightsfile()
  {
    return getusermailboxpath($_SESSION["MAILPATH"], $_SESSION["USERPATH"]) . "domain.dat";
  }

  function parsedomainfile($file, &$rights, &$optionlimits)
  {
    if (file_exists($file))
    {
      $list = file($file);
      // Rights
      if (eregi("RIGHTS=(.*)", $list[0], $arr)) $rights = strtoupper($arr[1]);

      // Option limits
      for ($i=0;$i<count($list);$i++)
      {
        if (eregi("OPTION=(.*)[:](.*)", $list[$i], $option)) $optionlimits[strtolower($option[1])] = $option[2];
      }
    }
  }

  // Loads the user rights
  function getuserrights(&$rights, &$optionlimits)
  {
    if ($_SESSION["ACCOUNT"] == 'ADMIN') return "*"; 

    // Defaults
    $rights = 'DEFAULTRIGHTS';
    $optionlimits = array();
    
    // Global rights
    parsedomainfile($_SESSION["CONFIGPATH"] . "domain.dat", $rights, $optionlimits);
    

    // User specific rights
    parsedomainfile(getuserrightsfile(), $rights, $optionlimits);
  }

  function setsystemcookie($cookie, $value)
  {
    setcookie($cookie, $value, time()+60*60*24*7);
    $_COOKIE[$cookie] = $value;
  }
  
  function getfilevarpath($filename, $relative)
  {
    if (!($filename[1]==":") && !($filename[0]=="\\") && !($filename[0]=="/")) return $relative . $filename; else return $filename; 
  }

  function getdomainslimits()
  {
    global $domain;
    
    $limits = array();

    // Get list
    $domains = getdomainlist();

    // For every domain
    for ($i=0; $i<count($domains);$i++)
    {      
      $dom = $domains[$i]["DOMAIN"];
      
      // Open domain
      $domain->Open($dom);
      
      // Get limit
      $limit = $domain->GetProperty("d_accountnumber");
      
      // Add to list
      if ($limit) $limits[$dom] = $limit;
    }
    
    return $limits;
  }
  
  // Logs on the user
  function loginuser($username, $password, $interface, $method="")
  {
    global $SERVER_NAME;
    $user = createobject("account"); 
	
	// Authenticate    
	  $auth = $user->AuthenticateUserHash($username,$password, $SERVER_NAME,$method);
	  if ($auth) $auth = $user->ValidateUser();
    // Get user flags
    if ($auth) 
    { 
      $admin = $user->GetProperty("u_admin");
      $domainadmin = $user->GetProperty("u_domainadmin");
      if ($admin) $account = 'ADMIN';
      else if ($domainadmin) $account = 'DOMAINADMIN'; 
      else $auth = false;
    }
    
    logoutuser();
    
    // Cookie lang
    setsystemcookie('LANG', @$_REQUEST['language']);
	
	  setsystemcookie('GUI', @$interface);
	  setsystemcookie('CIPHER', @$_REQUEST['xcipher']);
    // Cookie skin
    setsystemcookie('SKIN', @$_REQUEST['skin']);

    // Do login stuff
    if ($auth && $account)
    {
      global $api, $domain;
      checkdomainobjects();

      $_SESSION["EMAIL"] = $user->EmailAddress;
      $_SESSION["USERPATH"] = $user->GetProperty("u_mailboxpath");
      $_SESSION["DOMAIN"] = $user->Domain;
      $_SESSION["ACCOUNT"] = $account;
      $_SESSION["TIMESTAMP"] = time();
      $_SESSION["INSTALLPATH"] = $api->GetProperty("c_installpath");
	    $_SESSION["GUI"] = $interface;
	    
      $_SESSION["TEMPPATH"] = getfilevarpath($api->GetProperty("C_System_Storage_Dir_TempPath"), $_SESSION[INSTALLPATH]);
      $_SESSION["MAILPATH"] = getfilevarpath($api->GetProperty("C_System_Storage_Dir_MailPath"), $_SESSION[INSTALLPATH]);
      $_SESSION["CONFIGPATH"] = $api->GetProperty("c_configpath");
      if ($account == 'DOMAINADMIN')
      {
        getuserrights($rights, $optionlimits);

        $_SESSION["RIGHTS"] = $rights;
        $_SESSION["LIMIT"] = $optionlimits;

        // Account limit
        $_SESSION["ACCOUNTLIMIT"] = getdomainslimits();
      }

    }
    
    return $auth;
  }
  
  // Logs out the user
  function logoutuser()
  {
    session_unset();
  }
  function checkuid($uid)
  {
  	if(time()>substr($uid,13)+300) return 0;
  	return 1;
  }
  function popuperror($error)
  {
    echo '<script>alert("' . htmlspecialchars($error) . '")</script>';
    die();
  }
function parseTime($srctype,$trgtype,$val)
{

      switch ($srctype){
        case "day":
          $val = $val * 24 * 256;
        break;
        case "seconds":
          $val = $val + 1;
          $val =  floor(($val / 3600) * 256);
        break;
        case "shour":
           $dotIndex = strpos( $val, ":" );
			     if ( $dotIndex === false ) $dotIndex = strlen( $val );
			     $valHour = substr( $val, 0, $dotIndex );
			     $valMin = substr( $val, $dotIndex + 1 );
			     if ( $valMin > 59 )
			     {
				      $valHour += floor( $valMin / 60 );
			         $valMin = $valMin % 60;
			     }
			     $valHour %= 24;
			     $val = $valHour * 256 + $valMin;
        break;
        case "hour":
          $val = $val * 256;
        break;
        case "min":
          $val = $val * 256 * 60;
        break;
      }
      
      switch ($trgtype){
        case "seconds":
          $val = $val * 3600 / 256;
        break;
        case "day":
          $val = $val / 24 / 256;
        break;
        case "shour":
          $valHour = floor( $val / 256 );
    	  	$valMin = $val - ( $valHour * 256 );
    	  	if ( $valMin > 59 )
    	  	{
    	  		$valHour += floor( $valMin / 60 );
    	  		$valMin = $valMin % 60;
    	  	}
    	  	$valHour %= 24;
    	  	if ( $valMin < 10 ) $valMin = "0".$valMin;
    	  	$val = $valHour.":".$valMin;
        break;
        case "hour":
          $val = $val / 256 ;
        break;
        case "min":
          $val = $val / 256 / 60;
        break;
      }
      return $val;
}
function getOSname()
{
  if (osvresion==1) $return = "linux";
  if (osversion==0) $return = "windows";
  return $return;
}

  function createobject($object)
  {
    switch ($object) {
      case "api": if (!USEAPIEXT) return new COM("MerakCOM.APIObject"); else return new MerakAPI();
      case "domain": if (!USEAPIEXT) return new COM("MerakCOM.DomainObject"); else return new MerakDomain();
      case "account": if (!USEAPIEXT) return new COM("MerakCOM.AccountObject"); else return new MerakAccount();
      case "remoteaccount": if (!USEAPIEXT) return new COM("MerakCOM.RemoteAccountObject"); else return new MerakRemoteAccount();
      case "schedule": if (!USEAPIEXT) return new COM("MerakCOM.ScheduleObject"); else return new MerakSchedule();
      case "statistics": if (!USEAPIEXT) return new COM("MerakCOM.StatisticsObject"); else return new MerakStatistics();
      case "gwapi": return new MerakGWAPI();
  
    }
  }
  
  function securepath($path) 
  { 
    if (ereg("(\.\.)|(:)", $path) || $path[0]=="/" || $path[0]=="\\") $path="";
    if (!$path) return false;
    return $path;   
  }
  
  function convertaccounts(&$items)
  {
      for($i = 0; $i<count($items); $i++)
      {
          $items[$i]["SORT"] = convertitem($items[$i]["SORT"]);
          $items[$i]["LABEL"] = convertitem($items[$i]["LABEL"]);
          $items[$i]["NAME"] = convertitem($items[$i]["NAME"]);
      }
  }    
  function convertdomains(&$items)
  {
      for($i = 0; $i<count($items); $i++)
      {
          $items[$i]["DESC"] = convertitem($items[$i]["DESC"]);
          $items[$i]["DOMAIN"] = convertitem($items[$i]["DOMAIN"]);
      }
  }
  
  function convertitem($item)
  {
    global $encoding;
    return str_replace("'","\'",$item);
  }
  
  function checkwizardaccessrights($wizard)
  {
        //Allowed wizards for domainadmin
        $DAWizards = array(0=>'wizard.account.php');
        
        //Return wizard
        switch ($_SESSION['ACCOUNT'])
        {
              case "ADMIN":
                    return $wizard;
              break;
              case "DOMAINADMIN":
                    if (in_array(strtolower($wizard),$DAWizards))
                          return $wizard;
              break;
        }     
        return false;
  }
  
  
	function getIMAPMailboxes($server, $port, $username, $password)
	{
		/* FIXME: SSL flag? */
		$attr = '';
		if ($port == 993)
			$attr .= '/ssl/novalidate-cert';
 
		$port = $port ? (':' . $port) : '';
    if ($port == ':110') $port.='/pop3/notls';
    
		$server = '{' . $server . $port .  $attr . '}';

		/* Open the IMAP stream. */
		$imap = @imap_open($this->server, $username, $password);
		
		if ($imap === false)
      return false;

		/* Get the mailbox hierarchy delimiter. */
		$list = imap_getmailboxes($imap, $server, 'INBOX');  
		return $list;
  }
  
  
	function getMailboxes($formapi)
	{
	      global $mailboxPath;
        $path = $formapi->getProperty("U_MailBoxPath");
    	  $mailboxes = array();
    	  
        $api = new MerakAPI();
    	  $mailboxPath = $api->GetProperty("C_System_Storage_Dir_MailPath").$path;
    	  
        $itm->name = "INBOX";
        $itm->delimiter = '/';
        $itm->rights = 0;
        
        $mailboxes[] = $itm;

        $mailboxes = array_merge($mailboxes, mailboxDirectories($mailboxPath));
        
        return $mailboxes;
  }
  
	function mailboxDirectories($path)
  {
        global $mailboxPath;
        $mailboxes = array();
       
				$items = glob($path."*",GLOB_ONLYDIR);

        if ($items) foreach($items as $item)
    	  {  
              $itempath = $item.'/';
              $firstChar = $item{strlen($path)};
    	        $item = substr($item, strlen($mailboxPath));
              if ($firstChar!='~' && strtolower($item)!='inbox') 
              {
                    unset($itm);
										$itm->name = $item;
                    $itm->delimiter = '/';
                    $itm->rights = 255; // Full rights
                    $mailboxes[] = $itm;
              }
              if (!is_array($mailboxes)) $mailboxes = array();
              if (!strpos($itempath,'~'))$mailboxes = array_merge($mailboxes,mailboxDirectories($itempath));

        } 
        return $mailboxes; 
  }
  
    //This function is an altenative to the standard
    //explode funct. but it unsets the last element in array
    //(for strings with separator at the end)
    function explode_j($sep,$string)
    {
      $return = explode($sep,$string);
      unset($return[count($return)-1]);
      return $return;
    }
?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/admin/inc/function.php <==
<?
  define('SESSIONTIMEOUT', 240);
  define('DEFAULTRIGHTS', "UMLG");

  // Validates the current session  
  function checksession()
  { 
    global $alang;

    $sess = true;

    if (!$_SESSION["EMAIL"]) $sess = false; else
    if ($_SESSION["TIMESTAMP"] + mktime(SESSIONTIMEOUT / 60) < time()) $sess = false;
    if (!$sess)
    {     
      // Open login page in parent window
      $dieredirect = '<body onload="window.open(\'index.html?message='.urlencode($alang["TStrings_wa_str6"]).'\',\'_top\');"></body>';
      //header("Location: index.html?message=" . urlencode($alang["SESSION"]));
      die($dieredirect);
    }
  }
  function checkadminaccess()
  {
   if ($_SESSION["ACCOUNT"]!='ADMIN'){
   //header("Location: index.html?message=" . urlencode($alang[SESSION]));
   header("Location: index.html?messageid=TStrings_wa_str6");
   die();
   } 
  }

  function getstrvalue($value)
  {
    $value = str_replace("'","\'",$value);
    if ($value) return $value; else return "";
  }  

  function getlanguagelist()
  {
    global $lang_settings, $language;
    while(list($index, $value) = each($lang_settings))
      @$langs .= addselectoption($index, $value[0], $language);

    return $langs;
  }

  function getskinlist()
  {
    global $layout_settings, $layout;

    while(list($index, $value) = each($layout_settings))
      @$skins .= addselectoption($index, $value[0], $layout);

    return $skins;
  }

  function addselectoption($value, $label, $selected)
  {
    $option = '<option value="' . $value . '" ' . ($selected==$value?"selected":"") . '>' . $label . '</option>';
    return $option;
  }

  function getusermailboxpath($mailpath, $usermailboxpath)
  {
    return getfilevarpath($usermailboxpath, $mailpath);
  }
  
  function getdomainvalue($value,$isremote = 0)
  {
    $pos = strpos($value, "@");
    if ($pos) $value = substr($value, $pos+1, strlen($value));
    return $value;
  }

  function getaliasvalue($value)
  {
    $pos = strpos($value, "@");
    if ($pos) $value = substr($value, 0, $pos);
    return $value;
  }
  function mkdirtree($fpath)
  {
    if($fpath!="" && !file_exists($fpath))
    {
       $fpath2=str_replace("\\","/",$fpath);
       $exparr=explode("/",$fpath2);

       for ($i=0;$i<count($exparr);$i++)
       {
         $dirline.= $exparr[$i]."/";
         if(!file_exists($dirline)) @mkdir($dirline,0750);
       }
    }

    return true;
  }
  function checkapiobject()
  {
    global $api;
    
    if (!$api) $api = createobject("api"); 

  }
  
  function isuserright($right)
  {
    if ($_SESSION["RIGHTS"] == "*") return true;
    return (strpos($_SESSION["RIGHTS"], $right) === false)?false:true;
  }

  function getuserrightsfile()
  {
    return getusermailboxpath($_SESSION["MAILPATH"], $_SESSION["USERPATH"]) . "domain.dat";
  }

  function parsedomainfile($file, &$rights, &$optionlimits)
  {
    if (file_exists($file))
    {
      $list = file($file);
      // Rights
      if (eregi("RIGHTS=(.*)", $list[0], $arr)) $rights = strtoupper($arr[1]);

      // Option limits
      for ($i=0;$i<count($list);$i++)
      {
        if (eregi("OPTION=(.*)[:](.*)", $list[$i], $option)) $optionlimits[strtolower($option[1])] = $option[2];
      }
    }
  }

  // Loads the user rights
  function getuserrights(&$rights, &$optionlimits)
  {
    if ($_SESSION["ACCOUNT"] == 'ADMIN') return "*"; 

    // Defaults
    $rights = DEFAULTRIGHTS;
    $optionlimits = array();
    
    // Global rights
    parsedomainfile($_SESSION["CONFIGPATH"] . "domain.dat", $rights, $optionlimits);
    

    // User specific rights
    parsedomainfile(getuserrightsfile(), $rights, $optionlimits);

  }

  function setsystemcookie($cookie, $value)
  {
    setcookie($cookie, $value, time()+60*60*24*7);
    $_COOKIE[$cookie] = $value;
  }
  
  function getfilevarpath($filename, $relative)
  {
    if (!($filename[1]==":") && !($filename[0]=="\\") && !($filename[0]=="/")) return $relative . $filename; else return $filename; 
  }

  function getdomainslimits()
  {
    global $oDomain;
    
    $oDomain = createobject("domain");
    
    $limits = array();

    // Get list
    $domains = getdomainlist();

    // For every domain
    for ($i=0; $i<count($domains);$i++)
    {      
      $dom = $domains[$i]["DOMAIN"];
      
      // Open domain
      $oDomain->Open($dom);
      
      // Get limit
      $limit = $oDomain->GetProperty("d_accountnumber");
      
      // Add to list
      if ($limit) $limits[$dom] = $limit;
    }
    
    return $limits;
  }
  
  // Logs on the user
  function loginuser($username, $password, $interface, $method="")
  {
    global $SERVER_NAME;
    $user = createobject("account"); 
	
	// Authenticate    
	  $auth = $user->AuthenticateUserHash($username,$password, $SERVER_NAME,$method);
	  if ($auth) $auth = $user->ValidateUser();
    // Get user flags
    if ($auth) 
    { 
      $admin = $user->GetProperty("u_admin");
      $domainadmin = $user->GetProperty("u_domainadmin");
      if ($admin) $account = 'ADMIN';
      else if ($domainadmin) $account = 'DOMAINADMIN'; 
      else $auth = false;
    }
    
    logoutuser();
    
    // Cookie lang
    setsystemcookie('LANG', @$_REQUEST['language']);
	
	  setsystemcookie('GUI', @$interface);
	  setsystemcookie('CIPHER', @$_REQUEST['xcipher']);
    // Cookie skin
    setsystemcookie('SKIN', @$_REQUEST['skin']);

    // Do login stuff
    if ($auth && $account)
    {
      global $api, $domain;
      checkdomainobjects();

      $_SESSION["EMAIL"] = $user->EmailAddress;
      $_SESSION["USERPATH"] = $user->GetProperty("u_mailboxpath");
      $_SESSION["DOMAIN"] = $user->Domain;
      $_SESSION["ACCOUNT"] = $account;
      $_SESSION["TIMESTAMP"] = time();
      $_SESSION["INSTALLPATH"] = $api->GetProperty("c_installpath");
      $_SESSION["SPAMPATH"] = $api->GetProperty("c_spampath");
      if(!$_SESSION['SPAMPATH'])
        $_SESSION['SPAMPATH'] = $_SESSION["INSTALLPATH"].'spam/';
      $_SESSION['CALENDARPATH'] = $api->GetProperty("c_calendarpath");
      if(!$_SESSION['CALENDARPATH'])
        $_SESSION['CALENDARPATH'] = $_SESSION["INSTALLPATH"].'calendar/';
	    $_SESSION["GUI"] = $interface;
	    
      $_SESSION["TEMPPATH"] = getfilevarpath($api->GetProperty("C_System_Storage_Dir_TempPath"), $_SESSION[INSTALLPATH]);
      $_SESSION["MAILPATH"] = getfilevarpath($api->GetProperty("C_System_Storage_Dir_MailPath"), $_SESSION[INSTALLPATH]);
      $_SESSION["CONFIGPATH"] = $api->GetProperty("c_configpath");
      if ($account == 'DOMAINADMIN')
      {
        getuserrights($rights, $optionlimits);

        $_SESSION["RIGHTS"] = $rights;
        $_SESSION["LIMIT"] = $optionlimits;

        // Account limit
        $_SESSION["ACCOUNTLIMIT"] = getdomainslimits();
      }

    }
    
    return $auth;
  }
  
  // Logs out the user
  function logoutuser()
  {
    session_unset();
  }
  function checkuid($uid)
  {
  	if(time()>substr($uid,13)+300) return 0;
  	return 1;
  }
  function popuperror($error)
  {
    echo '<script>alert("' . htmlspecialchars($error) . '")</script>';
    die();
  }
function parseTime($val,$bSet = false)
{   
      if($bSet){
        if( ( ( $pos = strpos($val,":") ) !==false ) ){
          $hours = substr($val,0,$pos);
          $minutes = substr($val,$pos+1);
          $val = $hours*3600+$minutes*60;
        }else{
          $val = $val * 60;
        }
      }else{
        $arr['hours'] = floor($val/3600);
        $val -= $arr['hours']*3600;
        $arr['minutes'] = floor($val/60);
        $val -= $arr['minutes']*60;
        $arr['sec'] = $val;
        //FIXME
        if($arr['sec']==59){
          $arr['sec'] = 0;
          $arr['minutes'] += 1;
        }
        if(isset($arr['hours']) && isset($arr['minutes'])){
        	if($arr['hours']<10) $arr['hours'] = '0'.$arr['hours'];
        	if($arr['minutes']<10) $arr['minutes'] = '0'.$arr['minutes'];
        	
          $val = $arr['hours'] . ':' . $arr['minutes'];
        } else {
          if($arr['minutes']){
            $val = $arr['minutes'];
          }
        }
      }
      return $val;
}
function getOSname()
{
  if (osvresion==1) $return = "linux";
  if (osversion==0) $return = "windows";
  return $return;
}

  function createobject($object)
  {
    switch ($object) {
      case "api": if (!USEAPIEXT) return new COM("MerakCOM.APIObject"); else return new MerakAPI();
      case "domain": if (!USEAPIEXT) return new COM("MerakCOM.DomainObject"); else return new MerakDomain();
      case "account": if (!USEAPIEXT) return new COM("MerakCOM.AccountObject"); else return new MerakAccount();
      case "remoteaccount": if (!USEAPIEXT) return new COM("MerakCOM.RemoteAccountObject"); else return new MerakRemoteAccount();
      case "schedule": if (!USEAPIEXT) return new COM("MerakCOM.ScheduleObject"); else return new MerakSchedule();
      case "statistics": if (!USEAPIEXT) return new COM("MerakCOM.StatisticsObject"); else return new MerakStatistics();
      case "gwapi": return new MerakGWAPI();
  
    }
  }
  
  function securepath($path) 
  { 
    if (ereg("(\.\.)|(:)", $path) || $path[0]=="/" || $path[0]=="\\") $path="";
    if (!$path) return false;
    return $path;   
  }
  
  function convertaccounts(&$items)
  {
      for($i = 0; $i<count($items); $i++)
      {
          $items[$i]["SORT"] = convertitem($items[$i]["SORT"]);
          $items[$i]["LABEL"] = convertitem($items[$i]["LABEL"]);
          $items[$i]["NAME"] = convertitem($items[$i]["NAME"]);
      }
  }    
  function convertdomains(&$items)
  {
      for($i = 0; $i<count($items); $i++)
      {
          $items[$i]["DESC"] = convertitem($items[$i]["DESC"]);
          $items[$i]["DOMAIN"] = convertitem($items[$i]["DOMAIN"]);
      }
  }
  
  function convertitem($item)
  {
    global $encoding;
    return str_replace("'","\'",$item);
  }
  
  function checkwizardaccessrights($wizard)
  {
        //Allowed wizards for domainadmin
        $DAWizards = array(0=>'wizard.account.php');
        
        //Return wizard
        switch ($_SESSION['ACCOUNT'])
        {
              case "ADMIN":
                    return $wizard;
              break;
              case "DOMAINADMIN":
                    if (!in_array(strtolower($wizard),$DAWizards)) return false;
                    switch($wizard){
                      case 'wizard.account.php':
                        if(!isuserright("U")) return false;
                      break;
                    }
                    
                    return $wizard;
              break;
        }     
        return false;
  }
  
  
	function getIMAPMailboxes($server, $port, $username, $password)
	{
		/* FIXME: SSL flag? */
		$attr = '';
		if ($port == 993)
			$attr .= '/ssl/novalidate-cert';
 
		$port = $port ? (':' . $port) : '';
    if ($port == ':110') $port.='/pop3/notls';
    
		$server = '{' . $server . $port .  $attr . '}';

		/* Open the IMAP stream. */
		$imap = @imap_open($this->server, $username, $password);
		
		if ($imap === false)
      return false;

		/* Get the mailbox hierarchy delimiter. */
		$list = imap_getmailboxes($imap, $server, 'INBOX');  
		return $list;
  }
  
  
	function getMailboxes($formapi)
	{
	      global $mailboxPath;
        $path = $formapi->getProperty("U_MailBoxPath");
    	  $mailboxes = array();
    	  
        $api = new MerakAPI();
    	  $mailboxPath = $api->GetProperty("C_System_Storage_Dir_MailPath").$path;
    	  
        $itm->name = "INBOX";
        $itm->delimiter = '/';
        $itm->rights = 0;
        
        $mailboxes[] = $itm;

        $mailboxes = array_merge($mailboxes, mailboxDirectories($mailboxPath));
        
        return $mailboxes;
  }
  
	function mailboxDirectories($path)
  {
        global $mailboxPath;
        $mailboxes = array();
       
				$items = glob($path."*",GLOB_ONLYDIR);

        if ($items) foreach($items as $item)
    	  {  
              $itempath = $item.'/';
              $firstChar = $item{strlen($path)};
    	        $item = substr($item, strlen($mailboxPath));
              if ($firstChar!='~' && strtolower($item)!='inbox') 
              {
                    unset($itm);
										$itm->name = $item;
                    $itm->delimiter = '/';
                    $itm->rights = 255; // Full rights
                    $mailboxes[] = $itm;
              }
              if (!is_array($mailboxes)) $mailboxes = array();
              if (!strpos($itempath,'~'))$mailboxes = array_merge($mailboxes,mailboxDirectories($itempath));

        } 
        return $mailboxes; 
  }
  
    //This function is an altenative to the standard
    //explode funct. but it unsets the last element in array
    //(for strings with separator at the end)
    function explode_j($sep,$string)
    {
      $return = explode($sep,$string);
      unset($return[count($return)-1]);
      return $return;
    }
    define(E_DEFAULT,''); 
    define(E_FAILURE,-1); // Function failure
    define(E_LICENSE,-2); // Insufficient license
    define(E_PARAMS,-3); // Size of parameters too short
    define(E_PATH,-4); // Function failure
    define(E_CONFIG,-5); // Configuration not found
    define(E_PASSWORD,-6); // Password policy
    define(E_CONFLICT,-7); // Item already exists
    define(E_INVALID,-8);  // Item already exists
  
    function getErrorMsg($api){
      global $alang;
      switch($api->LastErr){
         case E_LICENSE:// Insufficient license
          $errorMsg = $alang['TStrings_cerrusers'];
         break;
         case E_PARAMS: // Size of parameters too short
          $errorMsg = $alang['TStrings_cbenamealias'];
         break;
         case E_CONFIG: // Configuration not found
          $errorMsg = $alang['TStrings_cbenamealias'];
         break;
         case E_PASSWORD: // Password policy
          $errorMsg = $alang['TStrings_cmailboxpasswordpolicy'];
         break;
         case E_CONFLICT: // Item already exists
          $errorMsg = $alang['TStrings_cmailboxpassword'];
         break;
         case E_INVALID: // Item already exists
          $errorMsg = $alang['TStrings_cinvalidchar'];
         break;
         
         case E_FAILURE:// Function failure
         case E_PATH:
         case E_DEFAULT:
         default:
          $errorMsg = $alang['TStrings_cparamserror'];
         break;
      }
      
      $errorMsg = explode("|",$errorMsg);
      $errorMsg = $errorMsg[0];
      
      return $errorMsg;
    }
    
    function getAccessMode($service,&$value)
    {
      global $formapi,$api;

      switch(strtolower($service)){
        case 'av_general':
          $mode = $api->GetProperty("C_".$service."_ProcessingMode");
          if($formapi->EmailAddress)
            $value = $formapi->GetProperty("U_AVSupport");

          $value = $api->GetProperty("C_AV_General_IntegratedAV")==0?0:$value; 
        break;
        case 'as_challenge':
          $mode = $api->GetProperty("C_".$service."_ProcessingMode");
          $dat = parsedatfile('spam.dat','spam2');
          if($formapi->EmailAddress)
            $value = $formapi->GetProperty("U_QuarantineSupport");
          $value = $dat['SpamChallenge']==0?0:$value;
          break;      
        case 'as_general':     
          $mode = $api->GetProperty("C_".$service."_ProcessingMode");
          if($formapi->EmailAddress)
            $value = $formapi->GetProperty("U_ASSupport");
          $value = $api->GetProperty("C_AS_General_Enable")==0?0:$value;
          
          break;  
        case 'gw_general':
          if($formapi->EmailAddress)
            $value = $formapi->GetProperty("U_GWSupport");
          $mode = $api->GetProperty("C_".str_replace("_general","",$service)."_ProcessingMode");
          $value = !$api->GetProperty("C_".$service."_Disable")==0?0:$value; 
        break;
        case 'im_general':    
          if($formapi->EmailAddress)
            $value = $formapi->GetProperty("U_IMSupport");
          $mode = $api->GetProperty("C_".str_replace("_general","",$service)."_ProcessingMode");
          $value = !$api->GetProperty("C_".$service."_Disable")==0?0:$value; 
          break;
        case 'syncml':
          if($formapi->EmailAddress)
            $value = $formapi->GetProperty("U_SyncMLSupport");
          $mode = $api->GetProperty("C_System_Services_".$service."_AccessMode");
          $dat = parsedatfile('syncml/config/settings.xml','syncml');
          $value = (!$dat['Disabled'])==0?0:$value;
          break;
        case 'pop3':
        case 'imap':
        case 'smtp':
        case 'webmail':    
          return true;
        break;
        case 'sip':
          if($formapi->EmailAddress)
            $value = $formapi->GetProperty("U_SIPSupport");
         $mode = $api->GetProperty("C_System_Services_SIP_Mode");
         $value =  $api->GetProperty("C_System_Services_SIP_Enable")==0?0:$value;
        break;
      }

      switch($mode){
        case 1:
          return true;
        case 0:
          if(!$formapi->EmailAddress)
            $value = 1;
        case 3:
          return false;
        case 5:
          if($formapi->EmailAddress)
            return false;
          else
            return true;
        case 7:
          break;
        case 9:
          if($formapi->EmailAddress)
            return true;
          else{
            $value = true;
            return false;
          }          
      }

      return true;
    }
?>
